#[unsafe(no_mangle)]pub extern "C" fn sched_yield() -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/sched_yield.html.
Force the running thread to relinquish the processor until it again becomes the head of its thread list.